#' @export
#' @author Victor Teh
#' @family legacy
#' @rdname defunct
qrMask <- function(...) { # nolint: object_name_linter.
  .Defunct("qr_code") # nocov
}
